% clustered returns a cell array consisting of points associated with nodes.
%   c = clustered(Input,weights)
%   Given weights a matrix of weights numbered 1..m, c is a cell array of 
%   size m such that c{j} = the set of input vectors Il from Input that
%   are associated with node j based on the distance of each input in Il 
%   from node j.
%   NOTE: this expects the input and weights to be of unit length. It does
%    not explicitly calculate the distance rather uses the maximum dot 
%    product
%
% Author: Dale Patterson
% $Version: 1.0.0$ $Date: 3.30.06 $
% 
function c = clustered(I,w);
[m,n] = size(w);
c = cell(m,1);
[v,j] = max(I*w',[],2);   % j = node of winner for each pt 1..p
for i=1:m
    c{i} = I(find(j==i),:);
end


