% load_som reads in the data saved from 
%   [np,i,p,w] = load_som(DataFile) reads the data from DataFile and loads
%   into np: a 1-3 vector for the network paramaters, i: the input a p*n 
%   matrix, p: params for each iteration, a 1-by-5-numIterations 
%   multidimensional array, w: weights for each iteration, a 
%   m-by-n-numIterations multidimensional array
%
%   Input:
%     DataFile - name of file to read data from
%
% Author: Dale Patterson
% $Version: 1.0.0 $ $Date: 4.03.06 $
% 
function [np,i,p,w] = load_som(Data)
% open the data file
[fid,fmsg] = fopen(Data,'r');
if fid == -1
    error('plot_som_error:cannotOpenDataFile',fmsg);
end

% read in network paramaters and input
np = fread(fid,[1,3]);
i = fread(fid,[np(1),np(2)],'double');

p = ones(1,5,120*np(1)+1) .* -1;
w = zeros(np(3),np(2),120*np(1)+1);

% read the data
page = 1;
while ~feof(fid)
    pparams = fread(fid,[1,5],'double');
    if ~isempty(pparams)
        p(:,:,page) = pparams;
        w(:,:,page) = fread(fid,[np(3),np(2)],'double');    
        page = page + 1;
    end
end

% close the file
fclose(fid);

% remove unused pages
k = find(p(1,1,:) ~= -1); % k = index of all valid pages
p = p(:,:,k);        
w = w(:,:,k);