% norm_circle normalizes [x,y] pairs. 
%   circle = norm_circle(Unnormalized)
%     circle is a vector of normalized [x,y] pairs such that each [x,y]
%     lies on a circle of radius 1 with origin at [0,0] assuming that each
%     [x,y] is in the range [-1,1]
%
% Author: Dale Patterson
% $Version: 1.0.0 $ $Date: 3.30.06 $
%
function c = norm_circle(U)
% get dimensions for U and report error if n is invalid
[m,n] = size(U);
if n ~= 2
    error('normCircle:invalidInputDimensions', ...
          'Input argument U must be a P-by-2 matrix');
end

c = U;
for i=1:m
    norm = nthroot(c(i,1)^2+c(i,2)^2,2);
    c(i,:) = c(i,:)./norm;
end