% som_plot_stats  plots different stats of a som computations.
%   som_plot_stats(DataFile,Type) plots the error per epoch of the data in
%   DataFile or a histogram of winner nodes during all iterations.
%
%   Input:
%     DataFile - name of file to read data from
%     type - 0: plot error
%            1: plot winner
%            2: plot area difference
%
% Author: Dale Patterson
% $Version: 1.0.3 $ $Date: 4.06.06 $
% 
function som_plot_stats(Data,type)
% open the data file
[fid,fmsg] = fopen(Data,'r');
if fid == -1
    error('plot_som_error:cannotOpenDataFile',fmsg);
end

% read in network paramaters and input
net_params = fread(fid,[1,3]);
p = net_params(1);
n = net_params(2);
m = net_params(3);
input = fread(fid,[p,n],'double');
% fid is currently at initial weights

% read period paramaters and weights from file
% som halts at 120 epochs, an epoch is of size p and we need one additional
% for the initial weights and period paramaters
params = ones(1,5,120*p+1) .* -1;
weights = zeros(m,n,120*p+1);

% read the data
page = 1;
while ~feof(fid)
    pparams = fread(fid,[1,5],'double');
    if ~isempty(pparams)
        params(:,:,page) = pparams;
        weights(:,:,page) = fread(fid,[m,n],'double');    
        page = page + 1;
    end
end

% close the file
fclose(fid);

% remove unused pages
k = find(params(1,1,:) ~= -1); % k = index of all valid pages
params = params(:,:,k);        
weights = weights(:,:,k);

% remove the initial paramaters and weights
params = params(:,:,2:end);
weights = weights(:,:,2:end);

% data used by both plotting
pages = size(params,3);
    epochs = pages/p;

if type == 0 % plots error over epochs
    % for avg squared distance, need to sum up epochs and divide by size
    avgErr = zeros(1,epochs);

    j=1;
    for i=0:p:pages-p
        avgErr(j) = sum(params(1,4,i+1:i+p))/p;
        j = j+1;
    end

    % draw the plot
    plot(1:epochs,avgErr);
    ylim([0 max(avgErr)+0.05]);
    xlabel('Epochs');
    ylabel('Avg. Squared Distance');
    title(['Average Squared Distance over ',num2str(epochs),' epochs']);
elseif type == 1 % plot number of times each node is winner
    wins = zeros(m,1);
    for i=1:m
        wins(i) = size(find(params(:,5,:)==i),1);
    end
    wins = wins ./ pages;
    bar(wins);
    xlabel('Node');
    ylabel('Average Number of Wins');
    title(['Average Wins Per Node over ',num2str(epochs), ' epochs']);
else % plot difference in area
    t = 0:pi/20:2*pi;          % plot a yellow circle of
    fill(sin(t),cos(t),'y');   % radius 1 @ origin [0,0]
    axis([-1.1,1.1,-1.1,1.1]); % move the axis out from edge of the circle
    axis square;               % and make x and y axis of same length
    set(gca,'XTick',0:-1);     % set x-axis ticks off
    set(gca,'YTick',0:-1);     % and y-axis ticks off   
    
    t1 = 0:pi/5.5:2*pi;        % plot an optimal red 12 node network
    hold on
        fill(sin(t1),cos(t1),'r');
    hold off
    
    w = weights(:,:,end);
    w = [w;w(1,:)];
    hold on
        fill(w(:,1),w(:,2),'w');
    hold off
    
    % set the title to area difference
%    areaC = polyarea(sin(t),cos(t));
    areaC = pi;
    areaIdeal = polyarea(sin(t1),cos(t1));
    areaW = polyarea(w(:,1),w(:,2));
    title({['Circle Area: (A_C) = ',num2str(areaC)]; ...
           ['Ideal Network Area: (A_I) = ',num2str(areaIdeal)]; ...
           ['Network Area: (A_N) = ',num2str(areaW)]; ...
           ['A_C - A_N = ',num2str(areaC-areaW)]; ...
           ['A_I - A_N = ',num2str(areaIdeal-areaW)]});
end